@@ -319,6 +319,16 @@ typedef struct pst_item_email {
     pst_string  supplementary_info;
     /** mapi element 0x0c20 PR_NDR_STATUS_CODE */
     int32_t     ndr_status_code;
+
+    // elements added for .msg processing
+    /** mapi element 0x0040 PR_RECEIVED_BY_NAME */
+    pst_string  outlook_received_name1;
+    /** mapi element 0x0c1a PR_SENDER_NAME */
+    pst_string  outlook_sender_name2;
+    /** mapi element 0x0e1d PR_NORMALIZED_SUBJECT */
+    pst_string  outlook_normalized_subject;
+    /** mapi element 0x300b PR_SEARCH_KEY */
+    pst_string  outlook_search_key;
 } pst_item_email;
 
 
@@ -596,6 +606,8 @@ typedef struct pst_item_attach {
     pst_string      filename2;
     /** mapi element 0x370e PR_ATTACH_MIME_TAG */
     pst_string      mimetype;
+    /** mapi element 0x3712 PR_ATTACH_CONTENT_ID  */
+    pst_string      content_id;
     /** mapi element 0x3701 PR_ATTACH_DATA_OBJ */
     pst_binary      data;
     /** only used if the attachment is by reference, in which case this is the id2 reference */
@@ -881,7 +893,7 @@ typedef struct pst_file {
     /** original file name when the file was opened */
     char*   fname;
     /** default character set for items without one */
-    char*   charset;
+    const char*   charset;
     /** the head and tail of the linked list of index structures */
     pst_index_ll *i_head, *i_tail;
     /** the head and tail of the top level of the descriptor tree */
@@ -1031,6 +1043,12 @@ pst_index_ll*   pst_getID(pst_file* pf, uint64_t i_id);
 size_t          pst_ff_getIDblock_dec(pst_file *pf, uint64_t i_id, char **buf);
 
 
+/** compare strings case-insensitive.
+ *  @return  -1 if a < b, 0 if a==b, 1 if a > b
+ */
+int pst_stricmp(char *a, char *b);
+
+
 /** fwrite with checking for null pointer.
  * @param ptr pointer to the buffer
  * @param size  size of each item
